@@ -381,6 +381,11 @@ class ServiceContainer(object):
                 self.dependencies.injections.all.worker_result(
                     worker_ctx, result, exc_info)
 
+                # we don't need this any more, and breaking the cycle means
+                # this can be reclaimed immediately, rather than waiting for a
+                # gc sweep
+                del exc_info
+
                 _log.debug('tearing down %s', worker_ctx,
                            extra=worker_ctx.extra_for_logging)
                 self.dependencies.all.worker_teardown(worker_ctx)
